package com.zx.dataservice.config;

import com.alibaba.druid.pool.DruidDataSource;
import com.zx.dataservice.utils.PropertiesUtil;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.mybatis.spring.SqlSessionTemplate;
import org.mybatis.spring.annotation.MapperScan;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

import javax.sql.DataSource;

@Configuration
@MapperScan(basePackages = {"com.zx.dataservice.mapper2"}, sqlSessionTemplateRef = "source2SqlSessionTemplate")
public class DataSourceConfig2 {

    @Bean(name = "source2DataSource")
//    @ConfigurationProperties(prefix = "spring.datasource.test2")
    public DataSource testDataSource() {
        DruidDataSource dataSource = new DruidDataSource();
        dataSource.setUrl(PropertiesUtil.getProperty("spring.datasource.test2.jdbc-Url"));
        dataSource.setUsername(PropertiesUtil.getProperty("spring.datasource.test2.username"));
        dataSource.setPassword(PropertiesUtil.getProperty("spring.datasource.test2.password"));
        dataSource.setDriverClassName(PropertiesUtil.getProperty("spring.datasource.test2.driver-class-name"));
        dataSource.setInitialSize(Integer.parseInt(PropertiesUtil.getProperty("spring.druid.initialSize")));
        dataSource.setMinIdle(Integer.parseInt(PropertiesUtil.getProperty("spring.druid.minIdle")));
        dataSource.setMaxActive(Integer.parseInt(PropertiesUtil.getProperty("spring.druid.maxActive")));
        dataSource.setMaxWait(Integer.parseInt(PropertiesUtil.getProperty("spring.druid.maxWait")));
        dataSource.setTimeBetweenEvictionRunsMillis(Long.parseLong(PropertiesUtil.getProperty("spring.druid.timeBetweenEvictionRunsMillis")));
        dataSource.setMinEvictableIdleTimeMillis(Long.parseLong(PropertiesUtil.getProperty("spring.druid.minEvictableIdleTimeMillis")));
        dataSource.setValidationQuery(PropertiesUtil.getProperty("spring.druid.validationQuery"));
        dataSource.setTestWhileIdle(Boolean.parseBoolean(PropertiesUtil.getProperty("spring.druid.testWhileIdle")));
        dataSource.setTestOnBorrow(Boolean.parseBoolean(PropertiesUtil.getProperty("spring.druid.testOnBorrow")));
        dataSource.setTestOnReturn(Boolean.parseBoolean(PropertiesUtil.getProperty("spring.druid.testOnReturn")));
        dataSource.setPoolPreparedStatements(Boolean.parseBoolean(PropertiesUtil.getProperty("spring.druid.poolPreparedStatements")));
        dataSource.setMaxPoolPreparedStatementPerConnectionSize(Integer.parseInt(PropertiesUtil.getProperty("spring.druid.maxPoolPreparedStatementPerConnectionSize")));
        dataSource.setRemoveAbandoned(Boolean.parseBoolean(PropertiesUtil.getProperty("spring.druid.removeAbandoned")));
        dataSource.setRemoveAbandonedTimeout(Integer.parseInt(PropertiesUtil.getProperty("spring.druid.removeAbandonedTimeout")));
        return dataSource;
    }

    @Bean(name = "source2SqlSessionFactory")
    public SqlSessionFactory source2SqlSessionFactory(@Qualifier("source2DataSource") DataSource dataSource) throws Exception {
        SqlSessionFactoryBean factoryBean = new SqlSessionFactoryBean();
        factoryBean.setDataSource(dataSource);
        factoryBean.setMapperLocations(new PathMatchingResourcePatternResolver().getResources("classpath:mybatis/mapper2/*.xml"));
        return factoryBean.getObject();
    }
    @Bean(name="source2TransactionManager")
    public DataSourceTransactionManager testTransactionManager(@Qualifier("source2DataSource") DataSource dataSource){
        return  new DataSourceTransactionManager(dataSource);
    }
    @Bean(name = "source2SqlSessionTemplate")
    public SqlSessionTemplate source2SqlSessionTemplate(@Qualifier("source2SqlSessionFactory") SqlSessionFactory sqlSessionFactory) {
        return new SqlSessionTemplate(sqlSessionFactory);
    }
}
